@@ -216,7 +216,7 @@ Provide a place lookup gazeteer based on files from geonames.org
             #flags = self.filter_results(place)
             self.process_results(place=place, flags=flags)
             # place.original_entry = place.get_long_name(None)
-            self.logger.debug(f'found geoid {place.georow_list[0]}')
+            #self.logger.debug(f'found geoid {place.georow_list[0]}')
             place.result_type = GeoUtil.Result.STRONG_MATCH
         else:
             place.result_type = GeoUtil.Result.NO_MATCH
